@@ -9,7 +9,7 @@ combining one, two, and three port networks.  See lcapy.oneport
 
 For detailed documentation see http://lcapy.readthedocs.io/en/latest
 
-Copyright 2014--2021 Michael Hayes, UCECE
+Copyright 2014--2022 Michael Hayes, UCECE
 """
 from __future__ import absolute_import, print_function
 del absolute_import, print_function
@@ -35,7 +35,6 @@ from .symbols import *
 from .circuit import *
 from .oneport import *
 from .twoport import *
-from .schematic import *
 from .expr import *
 from .voltage import voltage, noisevoltage, phasorvoltage
 from .current import current, noisecurrent, phasorcurrent
@@ -56,8 +55,6 @@ from .tmatrix import *
 from .vector import *
 from .statespace import *
 from .dtstatespace import *
-from .nodalanalysis import *
-from .loopanalysis import *
 from .laplace import *
 from .nettransform import *
 from .randomnetwork import *
@@ -81,22 +78,21 @@ from .units import volts, amperes, ohms, siemens, watts
 
 def show_version():
     """Show versions of Lcapy, SymPy, NumPy, MatplotLib, SciPy, and Python."""
-    
+
     from sys import version as python_version
     from sympy import __version__ as sympy_version
     from numpy import __version__ as numpy_version
-    from scipy import __version__ as scipy_version    
-    from matplotlib import __version__ as matplotlib_version    
+    from scipy import __version__ as scipy_version
+    from matplotlib import __version__ as matplotlib_version
 
-    print('Python: %s\nSymPy: %s\nNumPy: %s\nMatplotlib: %s\nSciPy: %s\nLcapy: %s' % 
+    print('Python: %s\nSymPy: %s\nNumPy: %s\nMatplotlib: %s\nSciPy: %s\nLcapy: %s' %
           (python_version, sympy_version, numpy_version,
            matplotlib_version, scipy_version, lcapy_version))
 
-# The following is to help sympify deal with j.   
+# The following is to help sympify deal with j.
 # A better fix might be to define an Lcapy class for j and to
 # use the __sympy_ method.
 from sympy.core.sympify import converter
 from sympy import Symbol
 converter['j'] = j
 converter[Symbol('j')] = j
-
