@@ -1,10 +1,11 @@
 """This module provides the EquipotentialNodes class.  This is used to
 find nodes connected by wires.
 
-Copyright 2020 Michael Hayes, UCECE
+Copyright 2020--2022 Michael Hayes, UCECE
 
 """
 
+
 class EquipotentialNodes(dict):
 
     def add(self, nodenames):
@@ -27,8 +28,12 @@ class EquipotentialNodes(dict):
             return
 
         if key1 != key2:
-            # Merge equipotential nodes.
-            self[key1].extend(self.pop(key2))
+            # Merge equipotential nodes.  Try to use
+            # primary nodes as the key.
+            if '_' in key2:
+                self[key1].extend(self.pop(key2))
+            else:
+                self[key2].extend(self.pop(key1))
 
     def add_wires(self, nodes):
 
@@ -36,5 +41,3 @@ class EquipotentialNodes(dict):
         for i in range(len(nodes)):
             for m in range(i + 1, len(nodes)):
                 self.add_wire(nodes[i], nodes[m])
-            
-
