@@ -16,8 +16,11 @@ __all__ = ('conjugate', 'sqrt', 'exp', 'log', 'log10', 'sin', 'cos',
            'rect', 'sinc', 'sincn', 'sincu', 'psinc', 'tri', 'trap',
            'ramp', 'rampstep', 'Sum', 'dtrect', 'dtsign', 'Piecewise',
            'Eq', 'Ne', 'Lt', 'Le', 'Gt', 'Ge', 'Derivative',
-           'Integral', 'Max', 'Min', 're', 'im', 'MatMul', 'MatAdd')
+           'Integral', 'Max', 'Min', 're', 'im', 'MatMul', 'MatAdd',
+           'degrees', 'radians')
 
+from .extrafunctions import Degrees as Degrees1
+from .extrafunctions import Radians as Radians1
 from .extrafunctions import UnitImpulse as UnitImpulse1
 from .extrafunctions import UnitStep as UnitStep1
 from .extrafunctions import sincn as sincn1
@@ -87,24 +90,29 @@ class Function(object):
 
         if (self.expr in (sym.sin, sym.cos, sym.tan, sym.cot, sym.exp,
                           sym.sinh, sym.cosh, sym.tanh, sym.coth)
-            and e_args[0].is_phase):
+                and e_args[0].is_phase):
             result.part = ''
         elif self.expr in (sym.atan, sym.atan2):
             result.units = uu.rad
         elif self.expr == sym.diff and isinstance(e_args[1], Expr):
             result.units = e_args[0].units / e_args[1].units
+        elif self.expr == Degrees1:
+            result.units = uu.deg
+        elif self.expr == Radians1:
+            result.units = uu.rad
         elif self.expr == sym.integrate:
             if isinstance(e_args[1], Expr):
                 result.units = e_args[0].units * e_args[1].units
             elif isinstance(e_args[1], tuple) and isinstance(e_args[1][0], Expr):
                 result.units = e_args[0].units * e_args[1][0].units
         elif self.expr is sym.DiracDelta and isinstance(e_args[0], Expr):
-                result.units = 1 / e_args[0].units
+            result.units = 1 / e_args[0].units
 
         return result
 
     def pdb(self):
-        import pdb; pdb.set_trace()
+        import pdb
+        pdb.set_trace()
         return self
 
 
@@ -178,6 +186,10 @@ gcd = Function(sym.gcd)
 
 sign = Function(sym.sign)
 
+degrees = Function(Degrees1)
+
+radians = Function(Radians1)
+
 diff = Function(sym.diff)
 
 integrate = Function(sym.integrate)
@@ -257,4 +269,4 @@ function_mapping = {sym.Heaviside: UnitStep1,
                     rect1: dtrect,
                     sym.sign: dtsign}
 
-from .expr import Expr, expr, delcapify
+from .expr import Expr, expr, delcapify  # nopep8
