@@ -28,14 +28,14 @@ class LoopAnalysis(object):
     ... W 1 5; up
     ... W 2 6; up
     ... C1 5 6; right=2
-    ...''')    
+    ...''')
 
     To perform nodal analysis in the time domain:
 
     >>> la = LoopAnalysis(cct)
-    
+
     To display the equations found by applying KVL around each mesh:
-    
+
     >>> la.mesh_equations().pprint()
 
     """
@@ -44,7 +44,7 @@ class LoopAnalysis(object):
     def from_circuit(cls, cct):
 
         return cls(cct)
-    
+
     def __init__(self, cct):
 
         self.cct = cct
@@ -68,8 +68,8 @@ class LoopAnalysis(object):
     def loops_by_cpt_name(self):
         """Return list of loops specified by cpt name."""
 
-        return self.cg.loops_by_cpt_name()        
-    
+        return self.cg.loops_by_cpt_name()
+
     @property
     def num_loops(self):
 
@@ -82,24 +82,27 @@ class LoopAnalysis(object):
 
         loops = self.loops()
         Nloops = len(loops)
-        
-        mesh_currents = ExprList([Iname('I_%d' % (m + 1), self.kind) for m in range(Nloops)])
+
+        mesh_currents = ExprList(
+            [Iname('I_%d' % (m + 1), self.kind) for m in range(Nloops)])
         return mesh_currents
 
-    def _make_equations(self):    
+    def _make_equations(self):
 
         if not self.cg.is_planar:
             raise ValueError('Circuit topology is not planar')
 
         if self.cct.is_superposition:
-            raise ValueError('Circuit has a mixture of ac/dc/transient sources')
-        
+            raise ValueError(
+                'Circuit has a mixture of ac/dc/transient sources')
+
         # This is work in progress to do mesh analysis.
 
         loops = self.loops()
         Nloops = len(loops)
 
-        mesh_currents = [Iname('I_%d' % (m + 1), self.kind) for m in range(Nloops)]
+        mesh_currents = [Iname('I_%d' % (m + 1), self.kind)
+                         for m in range(Nloops)]
         equations = {}
 
         for m, loop in enumerate(loops):
@@ -116,16 +119,17 @@ class LoopAnalysis(object):
 
                 if elt.is_current_source:
                     raise ValueError('TODO: handle current source in loop')
-                
+
                 # Map node names to equipotential node names.
-                nodenames = [self.cct.node_map[nodename] for nodename in elt.nodenames]
+                nodenames = [self.cct.node_map[nodename]
+                             for nodename in elt.nodenames]
 
                 is_reversed = nodenames[0] == loop1[j] and nodenames[1] == loop1[j + 1]
-                
+
                 if is_reversed:
                     current = -mesh_currents[m]
                 else:
-                    current = mesh_currents[m]                    
+                    current = mesh_currents[m]
 
                 for n, loop2 in enumerate(loops):
 
@@ -141,11 +145,11 @@ class LoopAnalysis(object):
                     # Determine polarity of cpt.
                     for l in range(len(loop2) - 1):
                         if (nodenames[0] == loop2[l] and
-                            nodenames[1] == loop2[l + 1]):
+                                nodenames[1] == loop2[l + 1]):
                             current -= mesh_currents[n]
                             break
                         elif (nodenames[1] == loop2[l] and
-                            nodenames[0] == loop2[l + 1]):
+                              nodenames[0] == loop2[l + 1]):
                             current += mesh_currents[n]
                             break
 
@@ -165,21 +169,22 @@ class LoopAnalysis(object):
 
         for current, (lhs, rhs) in self._equations.items():
             result.append(equation(lhs, rhs))
-        return result        
+        return result
 
     def mesh_equations(self):
         """Return mesh equations as a dict keyed by the mesh current."""
 
         result = ExprDict()
 
-        for current, (lhs, rhs) in self._equations.items():       
+        for current, (lhs, rhs) in self._equations.items():
             result[current] = equation(lhs, rhs)
         return result
 
     def _analyse(self):
 
         if self.kind == 'time':
-            raise ValueError('Cannot put time domain equations into matrix form')
+            raise ValueError(
+                'Cannot put time domain equations into matrix form')
 
         subsdict = {}
         for m, i in enumerate(self._unknowns):
@@ -188,17 +193,17 @@ class LoopAnalysis(object):
         exprs = []
         for node, (lhs, rhs) in self._equations.items():
             lhs = lhs.subs(subsdict).expr.expand()
-            rhs = rhs.subs(subsdict).expr.expand()            
+            rhs = rhs.subs(subsdict).expr.expand()
             exprs.append(lhs - rhs)
-            
+
         y = []
         for y1 in self._y:
-            y.append(y1.subs(subsdict).expr);
-        
+            y.append(y1.subs(subsdict).expr)
+
         A, b = sym.linear_eq_to_matrix(exprs, *y)
 
         y = [y1.expr for y1 in self._y]
-        return SystemEquations(A, b, y)        
+        return SystemEquations(A, b, y)
 
     @property
     def A(self):
@@ -210,17 +215,17 @@ class LoopAnalysis(object):
 
     @property
     def b(self):
-        """Return b vector where A y = b."""        
+        """Return b vector where A y = b."""
 
         if not hasattr(self, '_sys'):
             self._sys = self._analyse()
-        return matrix(self._sys.b)        
+        return matrix(self._sys.b)
 
     @property
     def y(self):
         """Return y vector where A y = b."""
         return self._y
-    
+
     def matrix_equations(self, form='default', invert=False):
         """Return the equations in matrix form.
 
@@ -233,12 +238,12 @@ class LoopAnalysis(object):
 
         If `invert` is True, evaluate the matrix inverse."""
 
-
         if not hasattr(self, '_sys'):
             self._sys = self._analyse()
         return self._sys.format(form, invert)
-    
-from .expr import ExprList, ExprDict, expr    
-from .current import Iname
-from .voltage import Vtype
-from .matrix import matrix
+
+
+from .expr import ExprList, ExprDict, expr  # nopep8
+from .current import Iname  # nopep8
+from .voltage import Vtype  # nopep8
+from .matrix import matrix  # nopep8
