@@ -1,16 +1,16 @@
 """
-This module performs schematic drawing using circuitikz from a netlist.
+This module performs schematic drawing using circuitikz from a netlist::
 
->>> from lcapy import Schematic
->>> sch = Schematic()
->>> sch.add('P1 1 0.1; down')
->>> sch.add('R1 3 1; right')
->>> sch.add('L1 2 3; right')
->>> sch.add('C1 3 0; down')
->>> sch.add('P2 2 0.2; down')
->>> sch.add('W 0 0.1; right')
->>> sch.add('W 0.2 0.2; right')
->>> sch.draw()
+    >>> from lcapy import Schematic
+    >>> sch = Schematic('''
+    ... P1 1 0.1; down
+    ... R1 3 1; right
+    ... L1 2 3; right
+    ... C1 3 0; down
+    ... P2 2 0.2; down
+    ... W 0 0.1; right
+    ... W 0.2 0.2; right''')
+    >>> sch.draw()
 
 Copyright 2014--2022 Michael Hayes, UCECE
 """
@@ -21,12 +21,14 @@ Copyright 2014--2022 Michael Hayes, UCECE
 
 
 from __future__ import print_function
-from .latex import latex_format_label, latex_format_node_label
+from .config import autoground_default
+from .latex import latex_format_label
 from .expr import Expr
 from . import schemcpts
 import sympy as sym
 from .engformatter import EngFormatter
 from .schemmisc import Pos
+from .schemnode import Node
 from .schemplacer import schemplacer
 from .opts import Opts
 from .netfile import NetfileMixin
@@ -34,15 +36,17 @@ from .system import LatexRunner, PDFConverter, tmpfilename
 from os import path, remove
 from collections import OrderedDict
 from warnings import warn
-import math
 
 
 __all__ = ('Schematic', )
 
+# Default dots per inch for png files
+PNG_DPI = 300
 
-def display_matplotlib(filename, dpi=150, scale=2):
 
-    from matplotlib.pyplot import figure, figaspect
+def display_matplotlib(filename, dpi=PNG_DPI, scale=2):
+
+    from matplotlib.pyplot import figure
     from matplotlib.image import imread
 
     img = imread(filename)
@@ -75,157 +79,20 @@ class SchematicOpts(Opts):
 
     def __init__(self):
 
-        super (SchematicOpts, self).__init__(
+        super(SchematicOpts, self).__init__(
             {'draw_nodes': 'primary',
              'label_values': True,
              'label_ids': True,
              'annotate_values': False,
              'label_nodes': 'primary',
-             'scale' : 1.0,
-             'dpi' : 150,
-             'cpt_size' : 1.5,
-             'node_spacing' : 2.0,
-             'help_lines' : 0.0,
-             'style' : 'american',
-             'voltage dir' : 'RP'})
-
-
-class Node(object):
-
-    def __init__(self, name):
-
-        self.name = name
-        self._port = False
-        self._count = 0
-        parts = name.split('_')
-        # Primary 1, 2, a, a_3.  Not primary _1, _2, _a, _a_3, 0_3, a_b_c
-        self.primary = (name[0] != '_' and len(parts) <= 2) and not (name[0].isdigit() and len(parts) != 1)
-
-        # See MX1.sch for example.
-        if '._' in name:
-            self.primary = False
-
-        self.elt_list = []
-        self.pos = 'unknown'
-        # Sanitised name
-        self.s = name.replace('.', '@')
-        self.label = latex_format_node_label(self.name)
-        self.labelpos = None
-        self.pin = False
-        self.pinlabel = ''
-        self.namepos = None
-        self.pinname = ''
-        self.pinpos = None
-        self.clock = False
-        self.auxiliary = None
-        # Reference to node that defines the pin
-        self.ref = None
-        # Node is connected to a ground, etc. (an implicit power
-        # supply connection)
-        self.implicit = False
-
-    @property
-    def basename(self):
-        fields = self.name.split('.')
-        return fields[-1]
-
-    @property
-    def cptname(self):
-        fields = self.name.split('.')
-        if len(fields) < 2:
-            return None
-        return fields[-2]
-
-    def __repr__(self):
-        return '%s @ (%s)' % (self.name, self.pos)
-
-    def append(self, elt):
-        """Add new element to the node"""
-
-        if elt.type == 'P':
-            self._port = True
-
-        self.elt_list.append(elt)
-        if elt.type not in ('A', 'O'):
-            self._count += 1
-
-    @property
-    def count(self):
-        """Number of elements (including wires but not open-circuits)
-        connected to the node"""
-
-        return self._count
-
-    def belongs(self, cpt_name):
-        return self.cptname == cpt_name
-
-    def visible(self, draw_nodes):
-        """Return true if node drawn.
-        `draw_nodes' can be `all', 'none', 'connections', 'primary', None,
-        True, or False."""
-
-        if self.auxiliary:
-            return False
-
-        if draw_nodes in ('all', True):
-            return True
-
-        if self.pin:
-            return False
-
-        if self.implicit:
-            return False
-
-        if self._port:
-            return True
-
-        if draw_nodes in ('none', None, False):
-            return False
-
-        # Implied port
-        if self.count == 1:
-            return True
-
-        if draw_nodes in ('connections', 'connected'):
-            return self.count > 2
-
-        if draw_nodes == 'primary':
-            return self.primary
-
-        raise ValueError('Unknown argument %s for draw_nodes' % draw_nodes)
-
-    @property
-    def port(self):
-        """Return true if node is a port"""
-
-        return self._port or self.count == 1
-
-    def show_label(self, label_nodes):
-
-        if self.label == '':
-            return False
-
-        name = self.basename
-
-        # pins is for backward compatibility
-        if label_nodes in ('none', 'pins', 'false', False):
-            return False
-        elif label_nodes in ('all', 'true', True):
-            return True
-        elif label_nodes == 'alpha':
-            return self.primary and name[0].isalpha()
-        elif label_nodes == 'primary':
-            return self.primary
-
-        # handle label_nodes = '{1, 2}' etc.
-        if label_nodes[0] == '{' and label_nodes[-1] == '}':
-            label_nodes = label_nodes[1:-1]
-        labels = [foo.strip() for foo in label_nodes.split(',')]
-        return self.label in labels
-
-    def debug(self):
-        print(' %s @ (%s), count=%d, pin=%s' % (self.name, self.pos,
-                                                self.count, self.pin))
+             'autoground': 'none',
+             'scale': 1.0,
+             'dpi': PNG_DPI,
+             'cpt_size': 1.5,
+             'node_spacing': 2.0,
+             'help_lines': 0.0,
+             'style': 'american',
+             'voltage_dir': 'RP'})
 
 
 class Schematic(NetfileMixin):
@@ -294,6 +161,26 @@ class Schematic(NetfileMixin):
 
         return node
 
+    def _format_name(self, cpt_type, cpt_id):
+
+        name = cpt_type
+        subscript = cpt_id
+        if len(name) > 1:
+            name = r'\mathrm{%s}' % name
+        if subscript != '':
+            if len(subscript) > 1:
+                subscript = r'\mathrm{%s}' % subscript
+            name = name + '_{%s}' % subscript
+        return latex_format_label('$' + name + '$')
+
+    def _format_expr(self, expr):
+
+        return Expr(expr, cache=False).latex_math()
+
+    def _format_value_units(self, value, units):
+
+        return EngFormatter().latex_math(value, units)
+
     def _cpt_add(self, cpt):
 
         if cpt.offset != 0 and len(cpt.node_names) == 2:
@@ -313,8 +200,10 @@ class Schematic(NetfileMixin):
                 size = -size
                 angle = -angle
 
-            w1 = 'W %s %s; rotate=%s, size=%s' % (n1, on1, cpt.angle + angle, size)
-            w2 = 'W %s %s; rotate=%s, size=%s' % (n2, on2, cpt.angle + angle, size)
+            w1 = 'W %s %s; rotate=%s, size=%s' % (
+                n1, on1, cpt.angle + angle, size)
+            w2 = 'W %s %s; rotate=%s, size=%s' % (
+                n2, on2, cpt.angle + angle, size)
 
             self.add(w1)
             self.add(w2)
@@ -332,24 +221,11 @@ class Schematic(NetfileMixin):
             self.add('%s; %s' % (net, cpt.opts))
             return
 
-        def tex_name(name, subscript=None):
-
-            if subscript is None:
-                subscript = ''
-
-            if len(name) > 1:
-                name = r'\mathrm{%s}' % name
-            if len(subscript) > 1:
-                subscript = r'\mathrm{%s}' % subscript
-            if len(subscript) == 0:
-                return name
-
-            return '%s_{%s}' % (name, subscript)
-
         # There are two possible labels for a component:
-        # 1. Component identifier, e.g., R1
+        # 1. Component name, e.g., R1
         # 2. Component value, expression, or symbol
-        id_label = tex_name(cpt.type, cpt.id)
+
+        id_label = self._format_name(cpt.type, cpt.id)
         value_label = None
 
         if cpt.type in ('O', 'P', 'W') or id_label.find('#') != -1:
@@ -358,6 +234,7 @@ class Schematic(NetfileMixin):
         if cpt.type in ('S', 'SW', 'U'):
             value_label = ''
 
+        unify = False
         if cpt.args != ():
 
             # TODO, extend for mechanical and acoustical components.
@@ -367,9 +244,9 @@ class Schematic(NetfileMixin):
             expr = cpt.args[0]
             if cpt.classname in ('Vstep', 'Istep'):
                 expr = '(%s) * Heaviside(t)' % expr
-                value_label = Expr(expr, cache=False).latex_math()
+                value_label = self._format_expr(expr)
             elif cpt.classname in ('Vs', 'Is'):
-                value_label = Expr(expr, cache=False).latex_math()
+                value_label = self._format_expr(expr)
             elif cpt.classname == 'TF':
                 expr = sym.sympify(expr)
                 if expr.is_Pow and expr.args[1] == -1:
@@ -381,27 +258,36 @@ class Schematic(NetfileMixin):
                 # control current is specified by a voltage source.
                 # The user will have to override manually.
                 expr = cpt.args[1]
-                value_label = Expr(expr, cache=False).latex_math()
+                value_label = self._format_expr(expr)
             elif cpt.classname not in ('TP',):
                 try:
                     # Handle things like 9/1000 that can occur
                     # when substituting cpt values.
                     value = float(sym.Rational(expr))
                     if cpt.type in units_map:
-                        value_label = EngFormatter().latex_math(value, units_map[cpt.type])
+                        value_label = self._format_value_units(
+                            value, units_map[cpt.type])
                     else:
-                        value_label = Expr(expr, cache=False).latex_math()
+                        value_label = self._format_expr(expr)
 
                 except (ValueError, TypeError):
                     # This catches non numeric arg.
-                    value_label = Expr(expr, cache=False).latex_math()
+                    value_label = self._format_expr(expr)
 
-        # Currently, we only annnotated the component with the value,
-        # expression, or symbol.  If this is not specified, it
-        # defaults to the component identifier.  Note, some objects
-        # we do not want to label, such as wires and ports.
+            # Ensure labels are the same when the value is not specified.
+            # This will prevent printing the name and value.
+            unify = expr == cpt.type + cpt.id
+
+            # Currently, we only annnotate the component with the value,
+            # expression, or symbol.  If this is not specified, it
+            # defaults to the component identifier.  Note, some objects
+            # we do not want to label, such as wires and ports.
         cpt.id_label = '' if id_label is None else latex_format_label(id_label)
-        cpt.value_label = cpt.id_label if value_label is None else latex_format_label(value_label)
+        cpt.value_label = cpt.id_label if value_label is None else latex_format_label(
+            value_label)
+
+        if unify:
+            cpt.value_label = cpt.id_label
 
         if cpt.opts_string != '':
             self.hints = True
@@ -422,9 +308,21 @@ class Schematic(NetfileMixin):
             for node in cpt.required_node_names:
                 self._node_add(node, cpt, auxiliary=False)
 
-    def _setup(self):
+    def _setup(self, autoground):
         # This is called before node positions are assigned.
 
+        if autoground in ('true', 'True', True):
+            autoground = autoground_default
+        elif autoground in (False, None, 'false', 'none'):
+            autoground = False
+
+        if autoground:
+            for elt in self.elements.values():
+                elt.autoground(autoground)
+
+        for elt in self.elements.values():
+            elt.split_nodes()
+
         for elt in self.elements.values():
             elt.setup()
 
@@ -432,7 +330,8 @@ class Schematic(NetfileMixin):
             if node.ref is not None:
                 continue
             if node.cptname is not None and not node.implicit:
-                raise ValueError('Unreferenced pin connection %s for %s' % (node.name, node.elt_list))
+                raise ValueError('Unreferenced pin connection %s for %s' % (
+                    node.name, node.elt_list))
 
     def make_graphs(self, debug=0):
 
@@ -452,8 +351,9 @@ class Schematic(NetfileMixin):
     def _tikz_draw(self, style_args='', **kwargs):
 
         method = kwargs.pop('method', 'graph')
+        autoground = kwargs.get('autoground', False)
 
-        self._setup()
+        self._setup(autoground)
 
         self._positions_calculate(method, self.debug)
 
@@ -465,13 +365,10 @@ class Schematic(NetfileMixin):
         if 'options' in kwargs:
             opts.append(kwargs.pop('options'))
 
-        if 'font' in kwargs:
-            font = kwargs.pop('font')
-            opts.append('font=' + font)
-
-        if 'voltage dir' in kwargs:
-            voltage_dir = kwargs.pop('voltage dir')
-            opts.append('voltage dir=' + voltage_dir)
+        global_options = ['font', 'voltage_dir', 'color']
+        for opt in global_options:
+            if opt in kwargs:
+                opts.append(opt.replace('_', ' ') + '=' + kwargs.pop(opt))
 
         s = r'\begin{tikzpicture}[%s]''\n' % ', '.join(opts)
 
@@ -480,13 +377,13 @@ class Schematic(NetfileMixin):
             s += '  ' + kwargs.pop('preamble') + '\n'
 
         help_lines = float(kwargs.pop('help_lines', 0))
-        color = kwargs.pop('color', 'blue')
+        help_lines_color = kwargs.pop('help_lines_color', 'blue')
         if help_lines != 0:
             start = Pos(-0.5, -0.5) * self.node_spacing
             stop = Pos(self.width + 0.5, self.height + 0.5) * self.node_spacing
 
             s += r'  \draw[help lines, %s] (%s) grid [xstep=%s, ystep=%s] (%s);''\n' % (
-                color, start, help_lines, help_lines, stop)
+                help_lines_color, start, help_lines, help_lines, stop)
 
         # Write coordinates.  TODO, not all coordinates are needed
         # so those can be weeded out to simplify the generated file.
@@ -532,7 +429,7 @@ class Schematic(NetfileMixin):
 
         self.debug = kwargs.pop('debug', 0)
         style = kwargs.pop('style', 'american')
-        self.dpi = float(kwargs.pop('dpi', 150))
+        self.dpi = float(kwargs.pop('dpi', PNG_DPI))
         self.cpt_size = float(kwargs.pop('cpt_size', 1.2))
         self.node_spacing = float(kwargs.pop('node_spacing', 2.0))
         self.scale = float(kwargs.pop('scale', 1.0))
@@ -645,7 +542,7 @@ class Schematic(NetfileMixin):
              'all' to show all nodes
            'label_nodes': True to label all nodes,
              False or 'none' to label no nodes,
-             'primary' to label primary nodes,
+             'primary' to label primary nodes (nodes without an underscore),
              'alpha' to label nodes starting with a letter,
              'pins' to label nodes that are pins on a chip,
              'all' to label all nodes,
@@ -655,12 +552,12 @@ class Schematic(NetfileMixin):
            'scale': schematic scale factor, default 1.0
            'node_spacing': spacing between component nodes, default 2.0
            'cpt_size': size of a component, default 1.5
-           'dpi': dots per inch for png files
-           'help_lines': distance between lines in grid, default 0.0 (disabled)
-           'debug': Non-zero to display debug information
+           'dpi': dots per inch for png files, default 300
+           'help_lines': distance between lines in grid, default 0 (disabled)
+           'debug': non-zero to display debug information
         """
 
-        # None means don't care, so remove.
+        # None means don't care, so remove
         for key in list(kwargs.keys()):
             if kwargs[key] is None:
                 kwargs.pop(key)
@@ -705,7 +602,7 @@ class Schematic(NetfileMixin):
                 return False
 
         if not self.hints:
-            raise RuntimeWarning('No schematic drawing hints provided!')
+            warn('No schematic drawing hints provided!')
 
         png = kwargs.pop('png', False)
         svg = kwargs.pop('svg', False)
@@ -764,6 +661,7 @@ class Schematic(NetfileMixin):
 
         self.tikz_draw(filename=filename, **kwargs)
 
+
 def test():
 
     sch = Schematic()
