@@ -11,28 +11,33 @@ from argparse import ArgumentParser
 import sys
 import os
 
-def schtex_exception(type, value, tb):
-   if hasattr(sys, 'ps1') or not sys.stderr.isatty():
-      # We are not in interactive mode or we don't have a tty-like
-      # device, so call the default hook
-      sys.__excepthook__(type, value, tb)
-   else:
-      import traceback, pdb
-      # We are in interactive mode, print the exception...
-      traceback.print_exception(type, value, tb)
-      print()
-      # ...then start the debugger in post-mortem mode.
-      pdb.pm()
 
-def main (argv=None):
+def schtex_exception(type, value, tb):
+    if hasattr(sys, 'ps1') or not sys.stderr.isatty():
+        # We are not in interactive mode or we don't have a tty-like
+        # device, so call the default hook
+        sys.__excepthook__(type, value, tb)
+    else:
+        import traceback
+        import pdb
+        # We are in interactive mode, print the exception...
+        traceback.print_exception(type, value, tb)
+        print()
+        # ...then start the debugger in post-mortem mode.
+        pdb.pm()
+
+
+def main(argv=None):
 
     if argv is None:
         argv = sys.argv
 
     version = __doc__.split('\n')[0]
 
-    parser = ArgumentParser(description='Convert Lcapy schematic to image file.')
-    parser.add_argument('--version', action='version', version=__doc__.split('\n')[0])
+    parser = ArgumentParser(
+        description='Convert Lcapy schematic to image file.')
+    parser.add_argument('--version', action='version',
+                        version=__doc__.split('\n')[0])
 
     parser.add_argument('--debug', type=int,
                         dest='debug', default=None,
@@ -70,6 +75,10 @@ def main (argv=None):
                         dest='label_values', default=None,
                         help="label values")
 
+    parser.add_argument('--autoground', type=str,
+                        dest='autoground', default=None,
+                        help='autoground, choice: none, cground, ground, nground, pground, rground, sground')
+
     parser.add_argument('--noannotate-values', action='store_false',
                         dest='annotate_values', default=None,
                         help="don't annotate values separately from label")
@@ -169,6 +178,10 @@ def main (argv=None):
     parser.add_argument('--method', type=str, default='graph',
                         help='specify component placement algorithm')
 
+    parser.add_argument('--voltage-dir', type=str, default='RP',
+                        dest='voltage_dir',
+                        help="specify voltage dir: 'RP' (rising potential) or 'EF' (electric field)")
+
     parser.add_argument('filename', type=str, help='schematic filename')
 
     parser.add_argument('outfilename', type=str, nargs='?',
@@ -206,7 +219,7 @@ def main (argv=None):
         cct = cct.noisy()
 
     if args.renumber == 'all':
-       cct = cct.renumber()
+        cct = cct.renumber()
     elif args.renumber:
         parts = args.renumber.split(',')
         node_map = {}
@@ -219,17 +232,18 @@ def main (argv=None):
         cct = cct.renumber(node_map)
 
     if args.label_nodes not in ('none', 'all', 'alpha', 'pins', 'primary', False, None):
-        raise ValueError('Illegal option %s for label_nodes' % args.label_nodes)
+        raise ValueError('Illegal option %s for label_nodes' %
+                         args.label_nodes)
 
     if args.draw_nodes not in ('none', 'all', 'primary', 'connections',
                                False, None):
         raise ValueError('Illegal option %s for draw_nodes' % args.draw_nodes)
 
     if outfilename is not None:
-       base, ext = os.path.splitext(outfilename)
-       if ext == '.sch':
-          open(outfilename, 'w').write(str(cct))
-          return 0
+        base, ext = os.path.splitext(outfilename)
+        if ext == '.sch':
+            open(outfilename, 'w').write(str(cct))
+            return 0
 
     nosave = args.xgraph or args.ygraph
 
@@ -238,9 +252,9 @@ def main (argv=None):
         if args.options != None:
             kwargs['options'] = args.options
         if args.include != None:
-           kwargs['include'] = args.include
+            kwargs['include'] = args.include
         if args.preamble != None:
-           kwargs['preamble'] = args.preamble
+            kwargs['preamble'] = args.preamble
         if args.postamble != None:
             kwargs['postamble'] = args.postamble
         if args.style != None:
@@ -252,11 +266,12 @@ def main (argv=None):
                  draw_nodes=args.draw_nodes,
                  label_ids=args.label_ids,
                  label_values=args.label_values,
+                 autoground=args.autoground,
                  annotate_values=args.annotate_values,
                  filename=outfilename, scale=args.scale,
                  node_spacing=args.node_spacing, cpt_size=args.cpt_size,
                  help_lines=args.help_lines, debug=args.debug,
-                 method=args.method,
+                 method=args.method, voltage_dir=args.voltage_dir,
                  dpi=args.dpi, nosave=nosave, **kwargs)
 
     if args.xgraph:
@@ -268,10 +283,10 @@ def main (argv=None):
         ygraph.dot(outfilename, stage=args.stage)
 
     if args.circuitgraph:
-       from lcapy.circuitgraph import CircuitGraph
+        from lcapy.circuitgraph import CircuitGraph
 
-       cg = CircuitGraph(cct)
-       cg.draw(filename=outfilename)
+        cg = CircuitGraph(cct)
+        cg.draw(filename=outfilename)
 
     if args.show:
         show()
