@@ -205,7 +205,8 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
     def phasor(self, **assumptions):
         """Convert to phasor domain."""
 
-        result = PhasorFrequencyDomainExpression.from_laplace(self, **assumptions)
+        result = PhasorFrequencyDomainExpression.from_laplace(
+            self, **assumptions)
         return result
 
     def transient_response(self, tvector=None):
@@ -272,7 +273,7 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
 
         # Evaluate impulse response.
         th = arange(Nt) * dtval
-        H= LaplaceDomainExpression(expr1, **self.assumptions)
+        H = LaplaceDomainExpression(expr1, **self.assumptions)
         hvector = H.transient_response(th)
 
         ty = tvector
@@ -380,19 +381,20 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
         if method in ('impulse-invariance', 'adhoc'):
             result = expr._response_impulse_invariance(xvector, tvector, dtval)
         elif method in ('bilinear', 'tustin', 'trapezoidal'):
-            result = expr._response_bilinear(xvector, tvector, dtval, alpha=0.5)
+            result = expr._response_bilinear(
+                xvector, tvector, dtval, alpha=0.5)
         elif method in ('gbf', 'generalized-bilinear'):
-            result = expr._response_bilinear(xvector, tvector, dtval, alpha=alpha)
+            result = expr._response_bilinear(
+                xvector, tvector, dtval, alpha=alpha)
         elif method in ('euler', 'forward-diff', 'forward-euler'):
             result = expr._response_bilinear(xvector, tvector, dtval, alpha=0)
         elif method in ('backward-diff', 'backward-euler'):
-             result = expr._response_bilinear(xvector, tvector, dtval, alpha=1)
+            result = expr._response_bilinear(xvector, tvector, dtval, alpha=1)
         else:
             raise ValueError('Unknown method %s' % method)
 
         return result * dtval
 
-
     def state_space(self, form='CCF'):
         """Create state-space representation from transfer function.  Note,
         state-space representations are not unique and are determined
@@ -473,18 +475,22 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
 
         return self.plot(**kwargs)
 
-    def bode_plot(self, fvector=None, **kwargs):
+    def bode_plot(self, fvector=None, unwrap=True, **kwargs):
         """Plot frequency response for a frequency-domain phasor as a Bode
         plot (but without the straight line approximations).  fvector
         specifies the frequencies.  If it is a tuple (f1, f2), it sets
         the frequency limits.   Since a logarithmic frequency scale is used,
         f1 must be greater than 0.
 
-        This method makes the assumption that the expression is causal.
+        `unwrap` controls phase unwrapping (default True).
 
+        This method makes the assumption that the expression is causal.
+        Note, the Bode plot does not exist for marginally stable and unstable
+        systems since `jw` is outside the region of convergence.
         """
 
-        return self.fourier(causal=True).bode_plot(fvector, **kwargs)
+        return self.fourier(causal=True).bode_plot(fvector, unwrap=unwrap,
+                                                   **kwargs)
 
     def nyquist_plot(self, fvector=None, **kwargs):
         """Plot frequency response for a frequency-domain phasor as a Nyquist
@@ -497,7 +503,6 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
         The unit circle is shown by default.  This can be disabled with `unitcircle=False`.
 
         This method makes the assumption that the expression is causal.
-
         """
 
         return self.fourier(causal=True).nyquist_plot(fvector, **kwargs)
@@ -692,7 +697,8 @@ def pr2tf(poles, residues, var=None):
 
     if var is None:
         var = ssym
-    return LaplaceDomainTransferFunction(_pr2tf(sympify(poles), sympify(residues), var),
+    return LaplaceDomainTransferFunction(_pr2tf(sympify(poles),
+                                                sympify(residues), var),
                                          causal=True)
 
 
@@ -704,7 +710,7 @@ def sexpr(arg, **assumptions):
     return expr_make('laplace', arg, **assumptions)
 
 
-from .expressionclasses import expressionclasses
+from .expressionclasses import expressionclasses  # nopep8
 
 classes = expressionclasses.register('laplace', LaplaceDomainExpression)
 LaplaceDomainVoltage = classes['voltage']
@@ -713,8 +719,8 @@ LaplaceDomainAdmittance = classes['admittance']
 LaplaceDomainImpedance = classes['impedance']
 LaplaceDomainTransferFunction = classes['transfer']
 
-from .texpr import TimeDomainExpression, texpr
-from .phasor import PhasorFrequencyDomainExpression
+from .texpr import TimeDomainExpression, texpr  # nopep8
+from .phasor import PhasorFrequencyDomainExpression  # nopep8
 
 s = LaplaceDomainExpression('s')
 s.units = uu.rad / uu.s
