@@ -23,8 +23,9 @@ from .simplify import simplify_unit_impulse
 from .extrafunctions import (UnitImpulse, UnitStep, rect, dtrect, tri,
                              trap, dtsign, sincn, sincu, psinc, ramp,
                              rampstep)
+from warnings import warn
 
-__all__ = ('symsymbol', 'sympify', 'simplify', 'symbol_delete')
+__all__ = ('sympify', 'simplify', 'symbol_delete')
 
 
 global_dict = {}
@@ -98,9 +99,10 @@ def symbols_find(arg):
 
         return symbols
 
-    from .expr import Expr as LExpr
-    if isinstance(arg, LExpr):
-        arg = arg.expr
+    try:
+        arg = arg.sympy
+    except:
+        pass
 
     if not isinstance(arg, (Symbol, Expr, AppliedUndef)):
         return []
@@ -184,14 +186,7 @@ def parse(string, symbols=None, evaluate=True, local_dict=None,
         return s
 
     # Add newly defined symbols.
-    for symbol in s.atoms(Symbol):
-        name = symbol_name(symbol)
-        if name not in symbols:
-            if False:
-                print("Adding symbol '%s'" % name)
-
-            symbols[name] = symbol
-
+    symbols.add_from_expr(s)
     return s
 
 
@@ -259,7 +254,7 @@ def sympify1(arg, symbols=None, evaluate=True, override=False, rational=True,
 def sympify(expr, evaluate=True, override=False, rational=True, **assumptions):
     """Create a SymPy expression.
 
-    By default, symbols are assumed to be positive if no assumptions
+    By default, symbols are assumed to be positive reals if no assumptions
     are explicitly defined.
 
     Note, this will not modify previously defined symbols with the
@@ -271,56 +266,68 @@ def sympify(expr, evaluate=True, override=False, rational=True, **assumptions):
     previously defined by SymPy.
     """
 
-    if assumptions == {}:
+    if 'positive' in assumptions:
+        if not assumptions['positive']:
+            assumptions.pop('positive')
+    elif ('real' not in assumptions and 'complex' not in assumptions
+          and 'integer' not in assumptions):
         assumptions['positive'] = True
         # Note this implies that imag is False.   Also note that all
         # reals are considered complex (but with a zero imag part).
 
-    elif 'positive' in assumptions:
-        if not assumptions['positive']:
-            assumptions.pop('positive')
-
-    return sympify1(expr, state.context.symbols, evaluate, override,
+    return sympify1(expr, state.symbols, evaluate, override,
                     rational, **assumptions)
 
 
-def symsymbol1(name, override=True, force=False, **assumptions):
-
-    if override:
-        if name in state.context.domain_symbols:
-            if not force:
-                raise ValueError('Cannot override domain symbol %s without force=True' % name)
-            symbol_delete(name)
-
-        elif name in state.context.user_symbols:
-            symbol_delete(name)
-
-    return sympify(name, override=override, **assumptions)
-
-
-def symsymbol(name, force=False, **assumptions):
+def miscsymbol(name, force=False, **assumptions):
     """Create a SymPy symbol.
 
     This function allows symbol assumptions to be defined,
-    e.g., real=True, integer=True
+    e.g., `real=True, integer=True`
 
     By default, symbols are assumed to be positive unless real is
     defined.
 
+    If `name` is already a symbol, it is overridden unless it is
+    a domain symbol in which case `force` must be `True`.
+
     """
 
-    usym = symsymbol1(name, force=force, **assumptions)
-    state.global_context.user_symbols[name] = usym
-    return usym
+    return state.symbols.add_misc(name, force=force, **assumptions)
 
 
-def domainsymbol(name, **assumptions):
+def usersymbol(name, force=False, **assumptions):
+    """Create a SymPy symbol.
+
+    This function allows symbol assumptions to be defined,
+    e.g., `real=True, integer=True`
+
+    By default, symbols are assumed to be positive unless real is
+    defined.
+
+    If `name` is already a symbol, it is overridden unless it is
+    a domain symbol in which case `force` must be `True`.
+
+    """
+
+    try:
+        name = name.sympy
+    except:
+        pass
+    try:
+        # Handle sympy Symbol
+        name = name.name
+    except:
+        pass
+
+    return state.symbols.add_user(name, force=force, **assumptions)
+
+
+def domainsymbol(name: str, **assumptions):
     """Create a SymPy symbol and register as a domain symbol
     that should not be overwritten."""
 
-    sym = symsymbol1(name, **assumptions)
-    state.global_context.domain_symbols[name] = sym
-    return sym
+    return state.symbols.add_domain(name, **assumptions)
 
 
 def symsimplify(expr, var=None, **kwargs):
@@ -368,9 +375,10 @@ def simplify(expr, **kwargs):
     except:
         pass
 
-    from .expr import Expr as LExpr
-    if isinstance(expr, LExpr):
-        expr = expr.expr
+    try:
+        expr = expr.sympy
+    except:
+        pass
 
     return symsimplify(expr, **kwargs)
 
@@ -416,25 +424,12 @@ def symbol_delete(sym):
     """Delete symbol.  This is useful if a symbol needs to be redefined
     with different assumptions."""
 
-    state.context.symbols.pop(sym)
+    state.symbols.pop(sym)
 
 
 def symbol_map(name):
 
-    new = name
-    if not isinstance(name, str):
-        name = str(name)
-
-    # Replace symbol names with symbol definitions to
-    # avoid problems with real or positive attributes.
-    if name in state.context.symbols:
-        new = state.context.symbols[name]
-    elif name in state.global_context.symbols:
-        new = state.global_context.symbols[name]
-    else:
-        # Perhaps have symbol defined using sympy?
-        pass
-    return new
+    return state.symbols.lookup(name)
 
 
 # The following domain symbols are all SymPy symbols.
@@ -442,17 +437,17 @@ ssym = domainsymbol('s', complex=True)
 tsym = domainsymbol('t', real=True)
 fsym = domainsymbol('f', real=True)
 omegasym = domainsymbol('omega', real=True)
-omega0sym = symsymbol('omega_0', real=True)
-tausym = symsymbol('tau', real=True)
-nusym = symsymbol('nu', real=True)
+omega0sym = miscsymbol('omega_0', real=True)
+tausym = miscsymbol('tau', real=True)
+nusym = miscsymbol('nu', real=True)
 Omegasym = domainsymbol('Omega', real=True)
 Fsym = domainsymbol('F', real=True)
 nsym = domainsymbol('n', integer=True)
 ksym = domainsymbol('k', integer=True)
 zsym = domainsymbol('z', real=False)
 
-dt = symsymbol('Delta_t', real=True, positive=True)
-df = symsymbol('Delta_f', real=True, positive=True)
+dt = miscsymbol('Delta_t', real=True, positive=True)
+df = miscsymbol('Delta_f', real=True, positive=True)
 
 pi = sym.pi
 j = sym.I
@@ -462,7 +457,7 @@ one = sym.S.One
 
 # This is required for expr('I') to work as j but it prevents having
 # a current called I.
-state.context.symbols['I'] = sym.I
+state.symbols.register('I', sym.I, 'misc')
 
 try:
     from sympy.core.function import AppliedUndef
