@@ -1,10 +1,12 @@
 from lcapy import *
 from lcapy.texpr import TimeDomainVoltage, TimeDomainCurrent
-from lcapy.sexpr import LaplaceDomainVoltage
+from lcapy.sexpr import (LaplaceDomainVoltage, LaplaceDomainTransferFunction,
+                         LaplaceDomainImpedance, LaplaceDomainAdmittance)
 import unittest
 import sympy as sym
 import os
 
+
 class LcapyTester(unittest.TestCase):
 
     """Unit tests for lcapy circuits
@@ -31,8 +33,10 @@ class LcapyTester(unittest.TestCase):
         a.add('R1 1 2')
         a.add('C1 2 0')
 
-        self.assertEqual2(a.impedance(1, 2), R('R1').impedance, "Z incorrect for R1.")
-        self.assertEqual2(a.impedance(2, 0), C('C1').impedance, "Z incorrect for C1.")
+        self.assertEqual2(a.impedance(1, 2), R(
+            'R1').impedance, "Z incorrect for R1.")
+        self.assertEqual2(a.impedance(2, 0), C(
+            'C1').impedance, "Z incorrect for C1.")
         self.assertEqual2(
             a.impedance(1, 0), (R('R1') + C('C1')).impedance, "Z incorrect for R1 + C1.")
 
@@ -50,7 +54,6 @@ class LcapyTester(unittest.TestCase):
         # Use ac to force jomega form.
         self.assertEqual(a.ac().C1.B, admittance('-omega * C1'), "B incorrect")
 
-
     def test_VRC1(self):
         """Check VRC circuit
 
@@ -74,12 +77,12 @@ class LcapyTester(unittest.TestCase):
         # This has a non-invertible A matrix.
         # self.assertEqual2(a.admittance(1, 0), R(0).Y, "Y incorrect across V1")
 
-        self.assertEqual2(a.Voc(1, 0).s, V('V1 / s').Voc.s, "Voc incorrect across V1")
+        self.assertEqual2(a.Voc(1, 0).s, V('V1 / s').Voc.s,
+                          "Voc incorrect across V1")
         self.assertEqual(a.is_ivp, False, "Initial value problem incorrect")
         self.assertEqual(a.is_dc, False, "DC incorrect")
         self.assertEqual(a.is_ac, False, "AC incorrect")
 
-
     def test_VRL1(self):
         """Check VRL circuit
 
@@ -169,7 +172,6 @@ class LcapyTester(unittest.TestCase):
 
         self.assertEqual2(a.R2.V, V(10).Voc, "Incorrect voltage")
 
-
     def test_CCVS1(self):
         """Check CCVS
 
@@ -183,7 +185,6 @@ class LcapyTester(unittest.TestCase):
 
         self.assertEqual2(a.R2.V, V(10).Voc, "Incorrect voltage")
 
-
     def test_CCVS2(self):
         """Check CCVS
 
@@ -196,7 +197,6 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(a.H1.Voc, 0, "Incorrect cpt voltage")
         self.assertEqual(a.H1.Z, 0, "Incorrect cpt impedance")
 
-
     def test_V1(self):
         """Test V1"""
 
@@ -205,7 +205,6 @@ class LcapyTester(unittest.TestCase):
 
         self.assertEqual(a.V1.V.dc, voltage(10), "Incorrect voltage")
 
-
     def test_VRL1_dc(self):
         """Check VRL circuit at dc
 
@@ -219,7 +218,6 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(a.is_dc, True, "DC incorrect")
         self.assertEqual(a.is_ac, False, "AC incorrect")
 
-
     def test_VRL1_dc2(self):
         """Check VRL circuit at dc but with initial conditions
 
@@ -272,28 +270,6 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(a.R1.I, a.L1.I, "currents different")
         self.assertEqual(a.V1.I, a.L1.I, "currents different")
 
-
-    def test_transfer(self):
-        """Check transfer function
-
-        """
-
-        a = Circuit()
-        a.add('R1 1 0 1')
-        a.add('R2 1 2 2')
-        a.add('C1 2 0 1')
-
-        H = a.transfer(1, 0, 2, 0)
-        self.assertEqual2(H, 1 / (2 * s + 1), "Incorrect transfer function")
-        h = H.inverse_laplace()
-        self.assertEqual2(h, exp(-t / 2) * Heaviside(t) / 2,
-                          "Incorrect impulse response")
-        H1 = a.transfer((1, 0), (2, 0))
-        self.assertEqual2(H1, H, "Incorrect transfer function")
-        H2 = a.transfer('R1', 'C1')
-        self.assertEqual2(H2, H, "Incorrect transfer function")
-
-
     def test_VRC2(self):
         """Check VRC circuit with arbitrary s-domain source
 
@@ -317,7 +293,8 @@ class LcapyTester(unittest.TestCase):
         a.add('W 0 3; right')
 
         self.assertEqual(a.sub['s'].is_causal, True, "Causal incorrect")
-        self.assertEqual2(a.L1.v, voltage(2 * exp(-t) * u(t)), "L current incorrect")
+        self.assertEqual2(a.L1.v, voltage(
+            2 * exp(-t) * u(t)), "L current incorrect")
 
     def test_VR1_ac2(self):
         """Check VR circuit at ac for angular frequency 1
@@ -333,11 +310,14 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(a.is_ac, True, "AC incorrect")
         self.assertEqual(a.is_causal, False, "Causal incorrect")
         self.assertEqual(a.is_time_domain, True, "Time domain incorrect")
-        self.assertEqual(a.V1.v, TimeDomainVoltage('5*cos(t)'), "V1 voltage incorrect")
-        self.assertEqual(a.R1.v, TimeDomainVoltage('5*cos(t)'), "R1 voltage incorrect")
-        self.assertEqual(a.V1.i, TimeDomainCurrent('5*cos(t)'), "V1 current incorrect")
-        self.assertEqual(a.R1.i, TimeDomainCurrent('5*cos(t)'), "R1 current incorrect")
-
+        self.assertEqual(a.V1.v, TimeDomainVoltage(
+            '5*cos(t)'), "V1 voltage incorrect")
+        self.assertEqual(a.R1.v, TimeDomainVoltage(
+            '5*cos(t)'), "R1 voltage incorrect")
+        self.assertEqual(a.V1.i, TimeDomainCurrent(
+            '5*cos(t)'), "V1 current incorrect")
+        self.assertEqual(a.R1.i, TimeDomainCurrent(
+            '5*cos(t)'), "R1 current incorrect")
 
     def test_VRL1_ac2(self):
         """Check VRL circuit at ac for angular frequency 1
@@ -353,9 +333,10 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(a.is_ac, True, "AC incorrect")
         self.assertEqual(a.is_causal, False, "Causal incorrect")
         self.assertEqual(a.is_time_domain, False, "Time domain incorrect")
-        self.assertEqual(a.V1.v, TimeDomainVoltage('5*cos(t)'), "V1 voltage incorrect")
-        self.assertEqual(a.R1.i, TimeDomainCurrent('(4*sin(t)+3*cos(t))/5'), "R1 current incorrect")
-
+        self.assertEqual(a.V1.v, TimeDomainVoltage(
+            '5*cos(t)'), "V1 voltage incorrect")
+        self.assertEqual(a.R1.i, TimeDomainCurrent(
+            '(4*sin(t)+3*cos(t))/5'), "R1 current incorrect")
 
     def test_VRC_ivp(self):
         """Check VRC IVP"""
@@ -382,7 +363,6 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(a.V.I, a.C.I, "V + C current different")
         self.assertEqual(a.V.V,  a.R.V + a.C.V, "KVL fail")
 
-
     def test_VRL_ivp(self):
         """Check VRL IVP"""
 
@@ -420,7 +400,8 @@ class LcapyTester(unittest.TestCase):
         # positive node to the negative node.
         self.assertEqual(a.R.I, -a.L.I, "R + L current different")
         self.assertEqual(a.R.V, a.L.V, "R + L voltage different")
-        self.assertEqual(a.L.I(s), current('i0 / (s + R / L)'), "L current wrong")
+        self.assertEqual(a.L.I(s), current(
+            'i0 / (s + R / L)'), "L current wrong")
 
     def test_RC_ivp(self):
         """Check RC IVP"""
@@ -432,7 +413,8 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(a.is_ivp, True, "Initial value problem incorrect")
         self.assertEqual(a.R.I, -a.C.I, "R + C current different")
         self.assertEqual(a.R.V, a.C.V, "R + C voltage different")
-        self.assertEqual(a.C.I(s), current('-v0 / (s * R + 1 / C)'), "C current wrong")
+        self.assertEqual(a.C.I(s), current(
+            '-v0 / (s * R + 1 / C)'), "C current wrong")
 
     def test_sub(self):
         """Test sub-circuits"""
@@ -445,7 +427,6 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(a.ac().R1.V, 0, "AC model incorrect")
         self.assertEqual(a.dc().R1.V, 0, "DC model incorrect")
 
-
     def test_IV_series(self):
         """Test IV series"""
 
@@ -538,7 +519,6 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(a.R1.v, voltage('V1 * cos(omega_0 * t) * abs(omega_0) / omega_0'),
                          "coupling incorrect")
 
-
     def test_kill(self):
         """Test kill"""
 
@@ -559,8 +539,8 @@ class LcapyTester(unittest.TestCase):
 
         d = a.kill_except('V1')
 
-        self.assertEqual(d.R.V, voltage(6), "incorrect voltage with all killed except V1")
-
+        self.assertEqual(d.R.V, voltage(
+            6), "incorrect voltage with all killed except V1")
 
     def test_TF(self):
         """Test TF"""
@@ -569,7 +549,8 @@ class LcapyTester(unittest.TestCase):
         TF 2 0 1 0 k
         R 2 0""")
 
-        self.assertEqual(a.impedance(1, 0), impedance('R / k**2'), "incorrect impedance")
+        self.assertEqual(a.impedance(1, 0), impedance(
+            'R / k**2'), "incorrect impedance")
 
     def test_TVtriode(self):
         """ Test thermionic valve triode"""
@@ -615,9 +596,10 @@ class LcapyTester(unittest.TestCase):
         R4 3 4
         R5 4 0""")
 
-        self.assertEqual(a.in_series('R1'), set(('V', 'R2')), "in_series(R1)")
-        self.assertEqual(a.in_series('R3'), set(), "in_series(R3)")
-        self.assertEqual(a.in_series('R4'), set(('R5',)), "in_series(R4)")
+        self.assertEqual(set(a.in_series('R1')),
+                         set(('V', 'R2')), "in_series(R1)")
+        self.assertEqual(set(a.in_series('R3')), set(), "in_series(R3)")
+        self.assertEqual(set(a.in_series('R4')), set(('R5',)), "in_series(R4)")
 
     def test_in_parallel(self):
         """Test in_parallel"""
@@ -630,9 +612,11 @@ class LcapyTester(unittest.TestCase):
         R4 2 0
         R5 2 0""")
 
-        self.assertEqual(a.in_parallel('R1'), set(('V', 'R2')), "in_parallel(R1)")
-        self.assertEqual(a.in_parallel('R3'), set(), "in_parallel(R3)")
-        self.assertEqual(a.in_parallel('R4'), set(('R5', )), "in_parallel(R4)")
+        self.assertEqual(set(a.in_parallel('R1')),
+                         set(('V', 'R2')), "in_parallel(R1)")
+        self.assertEqual(set(a.in_parallel('R3')), set(), "in_parallel(R3)")
+        self.assertEqual(set(a.in_parallel('R4')),
+                         set(('R5', )), "in_parallel(R4)")
 
     def test_simplify(self):
         """Test simplify"""
@@ -643,7 +627,8 @@ class LcapyTester(unittest.TestCase):
 
         b = a.simplify()
 
-        self.assertEqual(b.impedance(1, 3), a.impedance(1, 3), "simplify series")
+        self.assertEqual(b.impedance(
+            1, 3), a.impedance(1, 3), "simplify series")
 
         a = Circuit("""
         R1 1 2
@@ -651,7 +636,8 @@ class LcapyTester(unittest.TestCase):
 
         b = a.simplify()
 
-        self.assertEqual(b.impedance(1, 2), a.impedance(1, 2), "simplify parallel")
+        self.assertEqual(b.impedance(1, 2), a.impedance(
+            1, 2), "simplify parallel")
 
     def test_VRL1_super(self):
         """Check VRL circuit
@@ -736,21 +722,26 @@ class LcapyTester(unittest.TestCase):
         a.add('R1 2 3')
 
         self.assertEqual(a.V1.is_source, True, "V is_source")
-        self.assertEqual(a.V1.is_dependent_source, False, "V is_dependent_source")
-        self.assertEqual(a.V1.is_independent_source, True, "V is_independent_source")
+        self.assertEqual(a.V1.is_dependent_source,
+                         False, "V is_dependent_source")
+        self.assertEqual(a.V1.is_independent_source,
+                         True, "V is_independent_source")
         self.assertEqual(a.V1.is_resistor, False, "V is_resistor")
 
         self.assertEqual(a.E1.is_source, True, "E is_source")
-        self.assertEqual(a.E1.is_dependent_source, True, "E is_dependent_source")
-        self.assertEqual(a.E1.is_independent_source, False, "E is_independent_source")
+        self.assertEqual(a.E1.is_dependent_source,
+                         True, "E is_dependent_source")
+        self.assertEqual(a.E1.is_independent_source,
+                         False, "E is_independent_source")
         self.assertEqual(a.E1.is_resistor, False, "E is_resistor")
 
         self.assertEqual(a.R1.is_source, False, "E is_source")
-        self.assertEqual(a.R1.is_dependent_source, False, "R is_dependent_source")
-        self.assertEqual(a.R1.is_independent_source, False, "R is_independent_source")
+        self.assertEqual(a.R1.is_dependent_source,
+                         False, "R is_dependent_source")
+        self.assertEqual(a.R1.is_independent_source,
+                         False, "R is_independent_source")
         self.assertEqual(a.R1.is_resistor, True, "E is_resistor")
 
-
     def test_TP(self):
         """Test TP"""
 
@@ -764,3 +755,51 @@ class LcapyTester(unittest.TestCase):
         e = d.circuit()
         e.add('V 1 0 15; down')
         self.assertEqual(e[3].V, 10, "Ymodel")
+
+    def test_transfer(self):
+        """Check transfer function
+
+        """
+
+        a = Circuit()
+        a.add('R1 1 0 1')
+        a.add('R2 1 2 2')
+        a.add('C1 2 0 1')
+
+        H = a.transfer(1, 0, 2, 0)
+        self.assertEqual2(H, 1 / (2 * s + 1), "Incorrect transfer function")
+        h = H.inverse_laplace()
+        self.assertEqual2(h, exp(-t / 2) * Heaviside(t) / 2,
+                          "Incorrect impulse response")
+        H1 = a.transfer((1, 0), (2, 0))
+        self.assertEqual2(H1, H, "Incorrect transfer function")
+        H2 = a.transfer('R1', 'C1')
+        self.assertEqual2(H2, H, "Incorrect transfer function")
+
+    def test_transfer(self):
+        """Check transfer functions
+
+        """
+
+        a = Circuit("""
+        P1 1 0
+        R1 1 2
+        R2 2 0
+        R3 2 3
+        P2 3 0""")
+
+        Av = a.voltage_gain('P1', 'P2')
+        self.assertEqual2(Av, LaplaceDomainTransferFunction('R2 / (R1 + R2)'),
+                          'voltage_gain')
+
+        Ai = a.current_gain('P1', 'P2')
+        self.assertEqual2(Ai, LaplaceDomainTransferFunction('-R2 / (R2 + R3)'),
+                          'current_gain')
+
+        Z = a.transimpedance('P1', 'P2')
+        self.assertEqual2(Z, LaplaceDomainImpedance('R2'),
+                          'transimpedance')
+
+        Y = a.transadmittance('P1', 'P2')
+        self.assertEqual2(Y, LaplaceDomainAdmittance('-R2 / (R1 * R2 + R1 * R3 + R2 * R3)'),
+                          'transadmittance')
