@@ -2,6 +2,7 @@ from lcapy import *
 from lcapy.phasor import PhasorFrequencyDomainExpression
 import unittest
 
+
 class LcapyTester(unittest.TestCase):
     """Unit tests for lcapy"""
 
@@ -21,14 +22,14 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(a.phase, 0, 'phase')
         self.assertEqual(a.magnitude, 3, 'magnitude')
         self.assertEqual(a.N, 3, 'N')
-        self.assertEqual(a.D, 1, 'D')                        
-        
+        self.assertEqual(a.D, 1, 'D')
+
         a = phasor(-3, omega=7)
-        self.assertEqual(a.phase, pi, 'phase')                
+        self.assertEqual(a.phase, pi, 'phase')
         self.assertEqual(a.magnitude, 3, 'magnitude')
 
         a = phasor(-3 + 4j, omega=7)
-        self.assertEqual(a.magnitude, 5, 'magnitude')                        
+        self.assertEqual(a.magnitude, 5, 'magnitude')
 
         v = voltage('cos(5 * t)')
         i = current('cos(5 * t)')
@@ -42,12 +43,12 @@ class LcapyTester(unittest.TestCase):
         V2 = phasorvoltage('cos(5 * t)')
         I2 = phasorcurrent('cos(5 * t)')
         self.assertEqual(V, V2, 'phasorvoltage')
-        self.assertEqual(I, I2, 'phasorcurrent')                
-        
-    def test_phasor_rms(self):        
+        self.assertEqual(I, I2, 'phasorcurrent')
+
+    def test_phasor_rms(self):
 
         p = phasor(2)
-        
+
         self.assertEqual(p.rms(), sqrt(2), 'rms')
 
     def test_phasor_mul_omega(self):
@@ -56,8 +57,8 @@ class LcapyTester(unittest.TestCase):
         q = p * omega
         r = phasor(2 * omega)
 
-        self.assertEqual(q, r, 'phasor(2) * omega')        
-        
+        self.assertEqual(q, r, 'phasor(2) * omega')
+
     def test_phasor_transform(self):
 
         H = 1 / s
@@ -66,9 +67,7 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(type(P), PhasorFrequencyDomainExpression, 'H(jw)')
 
         P = H(j * 2 * pi * f)
-        self.assertEqual(type(P), PhasorFrequencyDomainExpression, 'H(j * 2 * pi * f)')
+        self.assertEqual(
+            type(P), PhasorFrequencyDomainExpression, 'H(j * 2 * pi * f)')
 
-        self.assertEqual(P.var, None, 'P.var')        
-        
-        
-        
+        self.assertEqual(P.var, None, 'P.var')
