@@ -5,9 +5,11 @@ Copyright 2020--2022 Michael Hayes, UCECE
 """
 
 from sympy import Eq, Symbol, Piecewise, S, Heaviside
-from .sym import symsymbol
+from .state import state
+from .sym import miscsymbol
 from .utils import factor_const, remove_images
 from .extrafunctions import UnitStep
+from warnings import warn
 
 
 class Transformer(object):
@@ -27,8 +29,10 @@ class Transformer(object):
 
     def error(self, message=''):
         if message == '':
-            raise ValueError('Could not compute %s for %s' % (self.name, self.expr))
-        raise ValueError('Could not compute %s for %s: %s' % (self.name, self.expr, message))
+            raise ValueError('Could not compute %s for %s' %
+                             (self.name, self.expr))
+        raise ValueError('Could not compute %s for %s: %s' %
+                         (self.name, self.expr, message))
 
     def debug(self, message=''):
         if self._debug:
@@ -81,12 +85,13 @@ class Transformer(object):
 
         for dummy in dummies:
             if level == 0:
-                nu = symsymbol(dummy, **kwargs)
+                nu = miscsymbol(dummy, **kwargs)
             else:
-                nu = symsymbol(dummy + '_%d' % level, **kwargs)
+                nu = miscsymbol(dummy + '_%d' % level, **kwargs)
             if not expr.has(nu):
                 return nu
-        raise self.error('Dummy variable conflict with symbols: %s' % ', '.join(dummies))
+        raise self.error(
+            'Dummy variable conflict with symbols: %s' % ', '.join(dummies))
 
 
 class BilateralForwardTransformer(Transformer):
@@ -130,7 +135,7 @@ class UnilateralForwardTransformer(Transformer):
         for factor in expr.as_ordered_factors():
             if (factor.is_Function and
                 factor.func in (Heaviside, UnitStep) and
-                factor.args[0] == var):
+                    factor.args[0] == var):
                 pass
             else:
                 rest *= factor
@@ -177,18 +182,12 @@ class UnilateralInverseTransformer(Transformer):
 
         result = const * (cresult + uresult)
 
-        if kwargs.get('dc', False):
-            free_symbols = set([symbol.name for symbol in result.free_symbols])
-            if str(var) in free_symbols:
-                self.error('Weirdness, expecting dc.')
+        # The original signal can only be recovered from an inverse
+        # unilateral Laplace transform if we have the region of
+        # convergence.  In general, the result is unknown for t < 0
+        # unless we know the result is causal.
 
-        elif kwargs.get('ac', False):
-
-            if cresult != 0:
-                self.error('Weirdness, expecting ac.')
-            # TODO, perform more checking of the result.
-
-        elif not kwargs.get('causal', False):
+        if not kwargs.get('causal', False):
 
             if uresult != 0:
                 # Cannot determine result for var < 0
