@@ -11,6 +11,7 @@ from .sym import zsym
 
 __all__ = ('zseq', )
 
+
 class ZDomainSequence(ZDomain, Sequence):
     """Z-domain sequence."""
 
@@ -27,12 +28,12 @@ class ZDomainSequence(ZDomain, Sequence):
         N = len(vals)
         for ni in range(N):
             result = vals[ni] * z**ni
-            result = result.change(result, domain='discrete time')            
+            result = result.change(result, domain='discrete time')
             results.append(vals[ni] * z**ni)
 
         return self.change(results, domain='discrete time sequence')
-    
-    
+
+
 def zseq(arg, ni=None, origin=None):
     """Create a discrete-time domain Sequence from a tuple, list, ndarray, or str.
 
@@ -40,7 +41,7 @@ def zseq(arg, ni=None, origin=None):
 
     The sequence indices are specified with the optional `ni` argument.
     For example:
-    
+
     >>> a = zseq((1, 2, 3, 4), (-1, 0, 1, 2))
 
     If the `ni` argument is not specified, the sequence indices
@@ -56,11 +57,11 @@ def zseq(arg, ni=None, origin=None):
 
     >>> a = zseq('{1, _2, 3, 4}').n
     [-1, 0, 1, 2]
-    """    
-    
+    """
+
     return ZDomainSequence(arg, ni, origin)
 
-    
-from .expressionclasses import expressionclasses
+
+from .expressionclasses import expressionclasses  # nopep8
 
 expressionclasses.register('Z sequence', ZDomainSequence)
